==> impact-0.0.3.tar.gz: lib/7_Setting/2_Impact_Lang_Setting.dart <==
import 'package:flutter/material.dart';
import 'package:impact/0_Impact_Global/2_Shared_Preference.dart';
import 'package:impact/0_Impact_Global/3_Set_Text_Direction.dart';
import 'package:impact/0_Impact_Global/6_Set_Lang.dart';
import 'package:impact/8_Component/1_Menu_Button.dart';


class ImpactLangSetting extends StatefulWidget {
  var parent;

  ImpactLangSetting({
    required this.parent
  });

  @override
  State<StatefulWidget> createState() {
    return ImpactLangSettingState();
  }
}

class ImpactLangSettingState extends State<ImpactLangSetting> {
  late Widget ThemeChildBtn;
  String ThemeValue="";
  List<String> keys = <String>[
    'English',
    'Arabic',
  ];


  void SetBtn(){
    ThemeChildBtn =  Directionality(
      textDirection:TextDirection.rtl,
      child:Container(
        width: MediaQuery.of(context).size.width,
        height: 55,
        child: Padding(
          padding: const EdgeInsets.only(left: 16, right: 11),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.end,
            children: <Widget> [
              Icon(Icons.language,color:ImpactPrimaryColor),
              SizedBox(width:10,),
              Expanded(
                child:Text(
                    (ImpactSelectedLang==null || ImpactSelectedLang=="")?"اختيار":ImpactSelectedLang.toString(),
                    style:TextStyle(
                        color:ImpactPrimaryColor
                    ),
                    overflow: TextOverflow.ellipsis
                ),
              ),
              SizedBox(
                width: 22,
                height: 27,
                child: FittedBox(
                  fit: BoxFit.fill,
                  child: Icon(
                    Icons.arrow_drop_down,
                    color: ImpactPrimaryColor,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }



  @override
  Widget build(BuildContext context) {
    SetBtn();
    return Directionality(
      textDirection:TextDirection.rtl,
      child: MenuButton<String>(
        child: ThemeChildBtn,
        items: keys,
        selectedItem:ThemeValue,
        itemBuilder: (String value) => Directionality(
          textDirection:TextDirection.rtl,
          child: Container(
            width:MediaQuery.of(context).size.width,
            height: 55,
            alignment: Alignment.centerRight,
            padding: const EdgeInsets.symmetric(vertical: 0.0, horizontal: 16),
            child: Text(
              value,
              textDirection:TextDirection.rtl,
            ),
          ),
        ),
        toggledChild: Container(
          child: ThemeChildBtn,
        ),
        onItemSelected: (String value) async {
          SetBtn();
          setState(() {
            ImpactSelectedLang = value;
          });
          ImpactSetLang();
          ImpactSetTextDirection();
          ImpactSaveAndGetAllInfo();
          this.widget.parent.setState((){});
        },
        onMenuButtonToggle: (bool isToggle) {
          print(isToggle);
        },
      ),
    );
  }

}

==> impact-0.0.5.tar.gz: lib/7_Setting/2_Impact_Lang_Setting.dart <==
import 'package:flutter/material.dart';
import 'package:impact/0_Impact_Global/2_Shared_Preference.dart';
import 'package:impact/0_Impact_Global/3_Set_Text_Direction.dart';
import 'package:impact/0_Impact_Global/6_Set_Lang.dart';
import 'package:impact/8_Component/1_Menu_Button.dart';

class ImpactLangSetting extends StatefulWidget {
  var parent;
  bool? AllowMultipleLanguage;

  ImpactLangSetting({
    required this.parent,
    this.AllowMultipleLanguage
  });

  @override
  State<StatefulWidget> createState() {
    return ImpactLangSettingState();
  }
}

class ImpactLangSettingState extends State<ImpactLangSetting> {
  late Widget ThemeChildBtn;
  String ThemeValue="";

  List<String> keys = <String>[
    'English',
    'Arabic',
  ];

  List<String> keysMulti = <String>[
    'English',
    'Arabic',
    'Spanish',
    'Hindi',
    'French'
  ];


  void SetBtn(){
    ThemeChildBtn =  Directionality(
      textDirection:TextDirection.rtl,
      child:Container(
        width: MediaQuery.of(context).size.width,
        height: 55,
        child: Padding(
          padding: const EdgeInsets.only(left: 16, right: 11),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.end,
            children: <Widget> [
              Icon(Icons.language,color:ImpactPrimaryColor),
              SizedBox(width:10,),
              Expanded(
                child:Text(
                    (ImpactSelectedLang==null || ImpactSelectedLang=="")?"اختيار":ImpactSelectedLang.toString(),
                    style:TextStyle(
                        color:ImpactPrimaryColor
                    ),
                    overflow: TextOverflow.ellipsis
                ),
              ),
              SizedBox(
                width: 22,
                height: 27,
                child: FittedBox(
                  fit: BoxFit.fill,
                  child: Icon(
                    Icons.arrow_drop_down,
                    color: ImpactPrimaryColor,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }



  @override
  Widget build(BuildContext context) {
    SetBtn();
    return Directionality(
      textDirection:TextDirection.rtl,
      child: MenuButton<String>(
        child: ThemeChildBtn,
        items: (this.widget.AllowMultipleLanguage==true)?keysMulti:keys,
        selectedItem:ThemeValue,
        itemBuilder: (String value) => Directionality(
          textDirection:TextDirection.rtl,
          child: Container(
            width:MediaQuery.of(context).size.width,
            height: 55,
            alignment: Alignment.centerRight,
            padding: const EdgeInsets.symmetric(vertical: 0.0, horizontal: 16),
            child: Text(
              value,
              textDirection:TextDirection.rtl,
            ),
          ),
        ),
        toggledChild: Container(
          child: ThemeChildBtn,
        ),
        onItemSelected: (String value) async {
          SetBtn();
          setState(() {
            ImpactSelectedLang = value;
          });
          ImpactSetLang();
          ImpactSetTextDirection();
          ImpactSaveAndGetAllInfo();
          this.widget.parent.setState((){});
        },
        onMenuButtonToggle: (bool isToggle) {
          print(isToggle);
        },
      ),
    );
  }

}
